# Geniverse library
The Geniverse Project. Created by Victor Perez (@viccpoes) & Javier Ideami (@ideami).
Welcome to Geniverse. Build and train a universe of state of the art generative models and use powerful tools to generate and create.

Geniverse Alpha is the first creative platform we are building. It is a tool that allows you to generate visual assets using generative A.I. models through a minimalistic and powerful prompt engineering interface. 

![Alt text](./media/repo/geniverse1.jpg?raw=true "Geniverse")

With Geniverse Alpha you can:
- Guide the generative A.I. architectures by creating prompts within a flexible canvas, using texts and images.
- Generate results using different cutting edge generate A.I. architectures, being ab le to tweak the key settings of those models.
- Create videos of interpolations between a set of results, and create videos of zoom processes beginning at one of the results.
- Download the images and videos generated by the A.I.
- Access the tool from any device. Geniverse Alpha is optimized for the Chrome browser on PC and Android, and the Safari browser on iOS Mac and iPhone.

Forks are integrated into this repo using [submodules](https://gist.github.com/gitaarik/8735255). To properly load the forks, the following command must be executed:
```python
git submodule init
```
![Alt text](./media/repo/geniverse2.jpg?raw=true "Geniverse")
